@@ -5,6 +5,7 @@
 
 use std::fmt;
 
+use dialoguer::{theme, Confirm};
 use serde::{de::DeserializeOwned, Serialize};
 use structopt::StructOpt;
 // use structopt::clap;
@@ -216,6 +217,14 @@ enum Command {
         #[structopt(help = "Cluster token")]
         token: String,
     },
+    SaveConfigMap {
+        #[structopt(help = "Namespace to install statehub components")]
+        namespace: String,
+        #[structopt(help = "cluster name")]
+        cluster: v1::ClusterName,
+        #[structopt(help = "The name of the state to configure as default storage class")]
+        default_state: Option<String>,
+    },
 
     #[structopt(
         about = "List K8s namespaces",
@@ -292,19 +301,17 @@ impl Cli {
                 namespace,
                 skip_helm,
             } => {
-                let name = if let Some(name) = name.or_else(k8s::get_default_cluster_name) {
-                    name
-                } else {
-                    anyhow::bail!(
+                let name = name.or_else(k8s::get_cluster_name).ok_or_else(|| {
+                    anyhow::anyhow!(
                         "No default Kubernetes context found, need to provide cluster name"
-                    );
-                };
+                    )
+                })?;
                 let no_default_storage_class = if no_state {
                     true
                 } else {
                     no_default_storage_class
                 };
-                let default_storage_class = if no_default_storage_class {
+                let default_state = if no_default_storage_class {
                     None
                 } else if default_storage_class.is_none() {
                     states.first().map(|state| state.to_string())
@@ -313,7 +320,7 @@ impl Cli {
                 };
                 let states = if no_state { None } else { Some(states) };
                 let claim_unowned_states = !no_state_owner;
-                let helm = k8s::Helm::new(namespace, default_storage_class, skip_helm);
+                let helm = k8s::Helm::new(namespace, default_state, skip_helm);
                 statehub
                     .register_cluster(name, states, helm, claim_unowned_states)
                     .await
@@ -341,6 +348,15 @@ impl Cli {
             Command::SaveClusterToken { namespace, token } => {
                 statehub.save_cluster_token(namespace, token).await
             }
+            Command::SaveConfigMap {
+                namespace,
+                cluster,
+                default_state,
+            } => {
+                statehub
+                    .save_configmap(namespace, cluster, default_state)
+                    .await
+            }
             Command::ListNamespaces => statehub.list_namespaces().await,
             Command::ListNodes => statehub.list_nodes().await,
             Command::ListPods => statehub.list_pods().await,
@@ -354,17 +370,20 @@ pub(crate) struct StateHub {
     config: Config,
     api: api::Api,
     json: bool,
+    theme: theme::SimpleTheme,
     verbose: bool,
 }
 
 impl StateHub {
     fn new(config: Config, json: bool, verbose: bool) -> Self {
         let api = api::Api::new(config.api(), config.token(), verbose);
+        let theme = theme::SimpleTheme;
 
         Self {
             config,
             api,
             json,
+            theme,
             verbose,
         }
     }
@@ -601,6 +620,19 @@ impl StateHub {
         Ok(())
     }
 
+    async fn save_configmap(
+        &self,
+        namespace: String,
+        cluster: v1::ClusterName,
+        default_state: Option<String>,
+    ) -> anyhow::Result<()> {
+        let default_state = default_state.as_deref().unwrap_or("");
+        let api = self.api.url("");
+        let _configmap = k8s::store_configmap(&namespace, &cluster, default_state, &api).await?;
+
+        Ok(())
+    }
+
     async fn list_namespaces(&self) -> anyhow::Result<()> {
         k8s::list_namespaces()
             .await?
@@ -629,10 +661,18 @@ impl StateHub {
         self.config.save()
     }
 
-    fn confirm(&self, text: impl fmt::Display) -> bool {
-        print!("{}", text);
-        let yes: String = text_io::read!();
-        yes == "y" || yes == "yes"
+    fn confirm(&self, prompt: impl Into<String>) -> bool {
+        let theme = self.theme();
+        Confirm::with_theme(theme)
+            .with_prompt(prompt)
+            .default(false)
+            .show_default(true)
+            .interact()
+            .unwrap_or(false)
+    }
+
+    fn theme(&self) -> &dyn theme::Theme {
+        &self.theme
     }
 
     fn verbosely(&self, text: impl fmt::Display) {
